mod cli;
mod config;
mod solr;

use anyhow::{Context, Result};
use clap::StructOpt;
use cli::Cli;
use config::{config, drs_config};
use directories::ProjectDirs;
use tracing::Level;

const DOMAIN: &str = "de";
const ORGANIZATION: &str = "DKRZ";
const APP_NAME: &str = "freva";

#[tokio::main]
async fn main() -> Result<()> {
    let args = Cli::parse();

    tracing_subscriber::fmt()
        .with_max_level(log_level(args.verbosity))
        .init();

    let config_dir = match args.config_dir {
        Some(c) => c,
        None => ProjectDirs::from(DOMAIN, ORGANIZATION, APP_NAME)
            .context("no config dir given and no valid home directory found")?
            .config_dir()
            .to_owned(),
    };

    let conf = config(&config_dir)?;
    let drs_conf = drs_config(&config_dir)?;
    let ingest_opts = args.opts;

    solr::ingest(&ingest_opts, &conf, &drs_conf).await
}

fn log_level(verbosity: usize) -> Level {
    match verbosity {
        0 => Level::WARN,
        1 => Level::INFO,
        2 => Level::DEBUG,
        _ => Level::TRACE,
    }
}
